package egg_Energy

import (
	"applet/app/db"
	"applet/app/e"
	md "applet/app/md/institutional_management/egg_energy"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/implement"
	"github.com/gin-gonic/gin"
)

// GetActivePointsUserCoinList
// @Summary      制度中心-活跃积分持有者明细-活跃积分持有(获取)
// @Tags         公排管理
// @Description  活跃积分持有(获取)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Param    req    body	md.GetActivePointsUserCoinListReq 	false  "落地页不填页大小默认20条数据"
// @Success      200   {object}  md.GetActivePointsUserCoinListResp	"成功返回"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/activePointsUserCoinList [post]
func GetActivePointsUserCoinList(c *gin.Context) {
	var req *md.GetActivePointsUserCoinListReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	// 不传每页大小 认为落地页加载
	if req.PageSize == 0 {
		req.PageSize = 20
		req.Page = 1
	}

	kindList := make([]md.VirtualCoinListNode, 2)
	kind1 := md.VirtualCoinListNode{
		Kind:   1,
		CoinID: 1,
		Name:   "个人活跃账户币",
	}
	kind2 := md.VirtualCoinListNode{
		Kind:   2,
		CoinID: 2,
		Name:   "团队活跃账户币",
	}
	kindList = append(kindList, kind1, kind2)

	// 默认查询第一种货币持有数量列表
	if req.Kind == 0 {
		req.Kind = 1
	}
	coinID := kindList[req.Kind-1].CoinID
	amountDb := implement.NewUserVirtualAmountDb(db.Db)
	wallets, total, err3 := amountDb.UserVirtualAmountFindAndCountByCoinKind(coinID, req.Page, req.PageSize)
	if err3 != nil {
		e.OutErr(c, e.ERR_DB_ORM, err3.Error())
		return
	}
	activePointsWalletList := make([]md.ActivePointsWalletNode, len(wallets))
	userDb := implement.NewUserDb(db.Db)
	for _, wallet := range wallets {
		user, err4 := userDb.UserGetOneByParams(map[string]interface{}{
			"key":   "uid",
			"value": wallet.Id,
		})
		if err4 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err4.Error())
			return
		}
		activePointsWallet := md.ActivePointsWalletNode{
			Amount:    wallet.Amount,
			Uid:       user.Id,
			UserName:  user.Nickname,
			UserPhone: user.Phone,
		}
		activePointsWalletList = append(activePointsWalletList, activePointsWallet)
	}

	sumAmount, err5 := amountDb.UserVirtualAmountGetSumByCoinKind(coinID)
	if err5 != nil {
		e.OutErr(c, e.ERR_DB_ORM, err5.Error())
		return
	}

	resp := md.GetActivePointsUserCoinListResp{
		KindList:      kindList,
		List:          activePointsWalletList,
		SumUserAmount: sumAmount,
		Total:         total,
	}

	e.OutSuc(c, resp, nil)
}

// GetActivePointsUserCoinFlowList
// @Summary      制度中心-活跃积分持有者明细-活跃积分持有流水(查询)
// @Tags         公排管理
// @Description  活跃积分持有流水(查询)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Param    req    body	md.GetActivePointsUserCoinFlowListReq 	true  "至少传入 货币类型 ID 用户 UID 页数 每页大小"
// @Success      200   {object}  md.GetActivePointsUserCoinFlowListResp	"成功返回"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/activePointsUserCoinFlowList [post]
func GetActivePointsUserCoinFlowList(c *gin.Context) {
	var req *md.GetActivePointsUserCoinFlowListReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	coinFlowDb := implement.NewUserVirtualCoinFlowDb(db.Db)
	coinFlows, total, err := coinFlowDb.UserVirtualCoinFlowFindByCoinAndUser(req.Page, req.PageSize, req.CoinId, req.Uid, req.StartAt, req.EndAt, req.Direction)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	paginate := md.Paginate{
		Limit: req.PageSize,
		Page:  req.Page,
		Total: total,
	}

	map1 := md.DirectionMap{
		Key:   "1",
		Value: "收入",
	}
	map2 := md.DirectionMap{
		Key:   "2",
		Value: "支出",
	}

	direction := []md.DirectionMap{
		map1, map2,
	}
	selectData := md.SelectData{Direction: direction}

	var userVirtualCoinFlows []md.UserVirtualCoinFlow
	for _, coinFlow := range coinFlows {
		flow := md.UserVirtualCoinFlow{
			Id:           coinFlow.Id,
			Uid:          coinFlow.Uid,
			CoinId:       coinFlow.CoinId,
			Direction:    coinFlow.Direction,
			Title:        coinFlow.Title,
			Amount:       coinFlow.Amount,
			BeforeAmount: coinFlow.BeforeAmount,
			AfterAmount:  coinFlow.AfterAmount,
			SysFee:       coinFlow.SysFee,
			TransferType: coinFlow.TransferType,
			CreateAt:     coinFlow.CreateAt,
			UpdateAt:     coinFlow.UpdateAt,
		}
		userVirtualCoinFlows = append(userVirtualCoinFlows, flow)
	}

	resp := md.GetActivePointsUserCoinFlowListResp{
		Paginate:   paginate,
		List:       userVirtualCoinFlows,
		SelectData: selectData,
	}

	e.OutSuc(c, resp, nil)
}

// GetGreenEnergyUserCoinList
// @Summary      制度中心-绿色能量持有者明细-绿色能量(获取)
// @Tags         公排管理
// @Description  绿色能量(获取)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Param    req    body	md.GetGreenEnergyUserCoinListReq 	false  "落地页不填页大小默认20条数据"
// @Success      200   {object}  md.GetGreenEnergyUserCoinListResp	"成功返回"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/greenEnergyUserCoinList [post]
func GetGreenEnergyUserCoinList(c *gin.Context) {
	var req *md.GetGreenEnergyUserCoinListReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	// 不传每页大小 认为落地页加载
	if req.PageSize == 0 {
		req.PageSize = 20
		req.Page = 1
	}

	kindList := make([]md.VirtualCoinListNode, 2)
	kind1 := md.VirtualCoinListNode{
		Kind:   1,
		CoinID: 3,
		Name:   "个人绿色能量币",
	}
	kind2 := md.VirtualCoinListNode{
		Kind:   2,
		CoinID: 4,
		Name:   "团队绿色能量币",
	}
	kindList = append(kindList, kind1, kind2)

	// 默认查询第一种货币持有数量列表
	if req.Kind == 0 {
		req.Kind = 1
	}
	coinID := kindList[req.Kind-1].CoinID
	amountDb := implement.NewUserVirtualAmountDb(db.Db)
	wallets, total, err3 := amountDb.UserVirtualAmountFindAndCountByCoinKind(coinID, req.Page, req.PageSize)
	if err3 != nil {
		e.OutErr(c, e.ERR_DB_ORM, err3.Error())
		return
	}
	activePointsWalletList := make([]md.ActivePointsWalletNode, len(wallets))
	userDb := implement.NewUserDb(db.Db)
	for _, wallet := range wallets {
		user, err4 := userDb.UserGetOneByParams(map[string]interface{}{
			"key":   "uid",
			"value": wallet.Id,
		})
		if err4 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err4.Error())
			return
		}
		activePointsWallet := md.ActivePointsWalletNode{
			Amount:    wallet.Amount,
			Uid:       user.Id,
			UserName:  user.Nickname,
			UserPhone: user.Phone,
		}
		activePointsWalletList = append(activePointsWalletList, activePointsWallet)
	}

	sumAmount, err5 := amountDb.UserVirtualAmountGetSumByCoinKind(coinID)
	if err5 != nil {
		e.OutErr(c, e.ERR_DB_ORM, err5.Error())
		return
	}

	resp := md.GetGreenEnergyUserCoinListResp{
		KindList:      kindList,
		List:          activePointsWalletList,
		SumUserAmount: sumAmount,
		Total:         total,
	}

	e.OutSuc(c, resp, nil)
}

// GetGreenEnergyUserCoinFlowList
// @Summary      制度中心-绿色能量持有者明细-绿色能量持有流水(查询)
// @Tags         公排管理
// @Description  绿色能量持有流水(查询)
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Param    req    body	md.GetGreenEnergyUserCoinFlowListReq 	true  "至少传入 货币类型 ID 用户 UID 页数 每页大小"
// @Success      200   {object}  md.GetGreenEnergyUserCoinFlowListResp	"成功返回"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/institutionalManagement/eggEnergy/greenEnergyUserCoinFlowList [post]
func GetGreenEnergyUserCoinFlowList(c *gin.Context) {
	var req *md.GetGreenEnergyUserCoinFlowListReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}

	coinFlowDb := implement.NewUserVirtualCoinFlowDb(db.Db)
	coinFlows, total, err := coinFlowDb.UserVirtualCoinFlowFindByCoinAndUser(req.Page, req.PageSize, req.CoinId, req.Uid, req.StartAt, req.EndAt, req.Direction)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	paginate := md.Paginate{
		Limit: req.PageSize,
		Page:  req.Page,
		Total: total,
	}

	map1 := md.DirectionMap{
		Key:   "1",
		Value: "收入",
	}
	map2 := md.DirectionMap{
		Key:   "2",
		Value: "支出",
	}

	direction := []md.DirectionMap{
		map1, map2,
	}
	selectData := md.SelectData{Direction: direction}

	var userVirtualCoinFlows []md.UserVirtualCoinFlow
	for _, coinFlow := range coinFlows {
		flow := md.UserVirtualCoinFlow{
			Id:           coinFlow.Id,
			Uid:          coinFlow.Uid,
			CoinId:       coinFlow.CoinId,
			Direction:    coinFlow.Direction,
			Title:        coinFlow.Title,
			Amount:       coinFlow.Amount,
			BeforeAmount: coinFlow.BeforeAmount,
			AfterAmount:  coinFlow.AfterAmount,
			SysFee:       coinFlow.SysFee,
			TransferType: coinFlow.TransferType,
			CreateAt:     coinFlow.CreateAt,
			UpdateAt:     coinFlow.UpdateAt,
		}
		userVirtualCoinFlows = append(userVirtualCoinFlows, flow)
	}

	resp := md.GetGreenEnergyUserCoinFlowListResp{
		Paginate:   paginate,
		List:       userVirtualCoinFlows,
		SelectData: selectData,
	}

	e.OutSuc(c, resp, nil)
}
